@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: material.R 846 2012-03-06 20:43:37Z murdoch $
+## $Id: material.R 970 2013-09-16 01:18:23Z murdoch $
 ##
 
 ##
@@ -105,9 +105,11 @@ rgl.material <- function (
 
 rgl.getcolorcount <- function() .C( rgl_getcolorcount, count=integer(1) )$count
   
-rgl.getmaterial <- function(ncolors = rgl.getcolorcount(), id = NULL) {
+rgl.getmaterial <- function(ncolors, id = NULL) {
 
   if (!length(id)) id <- 0L
+  if (missing(ncolors))
+    ncolors <- if (id) rgl.attrib.count(id, "colors") else rgl.getcolorcount()
   
   idata <- rep(0, 25+3*ncolors)
   idata[1] <- ncolors
