@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: zzz.R 962 2013-09-02 15:02:07Z murdoch $
+## $Id: zzz.R 979 2013-10-06 14:54:36Z murdoch $
 ##
 
 ##
@@ -18,7 +18,6 @@
 {
   # OS-specific 
   initValue <- 0  
-  dll <- "rgl"
   
   onlyNULL <- rgl.useNULL()
   
@@ -31,7 +30,6 @@
       Sys.setenv("DYLD_LIBRARY_PATH"=gsub("/usr/X11R6/lib","",Sys.getenv("DYLD_LIBRARY_PATH")))
       if ( .Platform$GUI == "AQUA" && 
             file.exists(system.file("libs",.Platform$r_arch, "aglrgl.so", lib.loc=lib, package = pkg))) {
-          dll <- "aglrgl"
           initValue <- 1
       }
     }
@@ -42,33 +40,6 @@
     ## getWindowsHandle was numeric pre-2.6.0 
     if ( !is.null(frame) ) initValue <- getWindowsHandle("Console")
   } 
-  
-  useDynLib <- function(dll, entries) {
-      dll <- library.dynam(dll, pkg, lib.loc=lib)
-      names <- entries
-      if (length(names(entries))) {
-  	  rename <- names(entries) != ""
-  	  names[rename] <- names(entries)[rename]
-      }
-      for (i in seq_along(entries)) 
-      	  assign(names[i], getNativeSymbolInfo(entries[i], PACKAGE = dll),
-      	         envir = environment(.onLoad))
-  }
-          
-  entries <- c("rgl_init", "rgl_dev_open", "rgl_dev_close",
-	 "rgl_dev_getcurrent", "rgl_dev_list", "rgl_dev_setcurrent", "rgl_snapshot",
-	 "rgl_postscript", "rgl_material", "rgl_getmaterial",
-	 "rgl_getcolorcount", "rgl_dev_bringtotop", "rgl_clear",
-	 "rgl_pop", "rgl_id_count", "rgl_ids", "rgl_viewpoint",
-	 "rgl_attrib_count", "rgl_attrib", "rgl_text_attrib",
-	 "rgl_bg", "rgl_bbox", "rgl_light", "rgl_pixels", "rgl_planes", 
-	 "rgl_abclines", "rgl_primitive",
-	 "rgl_setMouseCallbacks", "rgl_surface", "rgl_spheres",
-	 "rgl_texts", "rgl_sprites", "rgl_user2window",
-	 "rgl_window2user", "rgl_selectstate", "rgl_setselectstate",
-	 rgl_par3d="par3d", "rgl_quit")
-	 
-  useDynLib(dll, entries)
  
   if (onlyNULL) {
     rglFonts(serif = rep("serif", 4), sans = rep("sans", 4), mono = rep("mono", 4), symbol = rep("symbol", 4))
