@@ -7,6 +7,8 @@
 #include "PrimitiveSet.hpp"
 #include <map>
 
+namespace rgl {
+
 class ABCLineSet : public LineSet {
 private:		/* Use parametrization (x,y,z) + s*(a,b,c) */
   int		nLines;
@@ -42,4 +44,6 @@ public:
 
 };
 
+} // namespace rgl
+
 #endif // PLANESET_HPP
