@@ -2,16 +2,16 @@
 #define BACKGROUND_HPP
 
 #include "Shape.hpp"
-
 #include "opengl.hpp"
+#include "SphereMesh.hpp"
+
+namespace rgl {
 
 //
 // CLASS
 //   Background
 //
 
-#include "SphereMesh.hpp"
-
 class Background : public Shape
 {
 public:
@@ -37,4 +37,6 @@ private:
   static Material defaultMaterial;
 };
 
+} // namespace rgl
+
 #endif // BACKGROUND_HPP
