@@ -1,11 +1,6 @@
 #ifndef LIGHT_HPP
 #define LIGHT_HPP
 
-//
-// CLASS
-//   Light
-//
-
 #include "SceneNode.hpp"
 
 #include "rglmath.h"
@@ -14,6 +9,13 @@
 
 #include "opengl.hpp"
 
+namespace rgl {
+
+//
+// CLASS
+//   Light
+//
+
 class Light : public SceneNode
 {
 public:
@@ -39,4 +41,6 @@ private:
   friend class Scene;
 };
 
+} // namespace rgl
+
 #endif // LIGHT_HPP
