@@ -7,6 +7,8 @@
 #include "PrimitiveSet.hpp"
 #include <map>
 
+namespace rgl {
+
 class PlaneSet : public TriangleSet {
 private:		/* Use parametrization ax + by + cz + d = 0 */
   int		nPlanes;
@@ -42,4 +44,6 @@ public:
   void getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result);  
 };
 
+} // namespace rgl
+
 #endif // PLANESET_HPP
