@@ -1,13 +1,17 @@
 #ifndef RENDERCONTEXT_HPP
 #define RENDERCONTEXT_HPP
 
+namespace rgl {
 class Scene;
 class Viewpoint;
 class GLFont;
+} // namespace rgl
 
 #include "rglmath.h"
 #include "opengl.hpp"
 
+namespace rgl {
+
 class RenderContext
 {
 public:
@@ -42,4 +46,6 @@ public:
   bool NULLActive;
 };
 
+} // namespace rgl
+
 #endif // RENDERCONTEXT_HPP
