@@ -3,10 +3,6 @@
 
 #include "Shape.hpp"
 
-//
-// TEXTSET
-//
-
 #include "render.h"
 #include "String.hpp"
 #include "glgui.hpp"
@@ -14,6 +10,12 @@
 #include "FTGL/ftgl.h"
 #endif
 
+namespace rgl {
+
+//
+// TEXTSET
+//
+
 class TextSet : public Shape {
 public:
   TextSet(Material& in_material, int in_ntexts, char** in_texts, double *in_center, 
@@ -46,5 +48,7 @@ private:
 
 };
 
+} // namespace rgl
+
 #endif // TEXTSET_HPP
 
