@@ -1,8 +1,10 @@
-using namespace std;
-#include "Texture.hpp"
 
+#include "Texture.hpp"
 #include "pixmap.h"
 
+using namespace std;
+using namespace rgl;
+
 //////////////////////////////////////////////////////////////////////////////
 //
 // CLASS
@@ -113,7 +115,7 @@ void Texture::getParameters(Type *out_type, bool *out_mipmap,
   strncpy(out_filename, filename, buflen);
 }
 
-unsigned int texsize(unsigned int s)
+static unsigned int texsize(unsigned int s)
 {
   return 1U << msb(s-1);
 }
@@ -126,7 +128,7 @@ static void printGluErrorMessage(GLint error)
   char buf[256];        
   gluError = gluErrorString (error);
   sprintf(buf, "GLU Library Error : %s", (const char*) gluError);
-  lib::printMessage(buf);
+  printMessage(buf);
 }
 
 void Texture::init(RenderContext* renderContext)
@@ -217,7 +219,7 @@ void Texture::init(RenderContext* renderContext)
     if ( (width > maxSize) || (height > maxSize) ) {
       char buf[256];
       sprintf(buf, "GL Library : Maximum texture size of %dx%d exceeded.\n(Perhaps enabling mipmapping could help.)", maxSize,maxSize);
-      lib::printMessage(buf);
+      printMessage(buf);
     } else if ( (pixmap->width != width) || ( pixmap->height != height) ) {
       char* data = new char[width * height * bytesperpixel];
       int gluError = gluScaleImage(format, pixmap->width, pixmap->height, gl_type, pixmap->data, width, height, gl_type, data);
