@@ -1,12 +1,13 @@
 #ifndef VIEWPOINT_HPP
 #define VIEWPOINT_HPP
 
-#include "opengl.hpp"
 #include "SceneNode.hpp"
 
 #include "render.h"
 #include "geom.hpp"
 
+namespace rgl {
+
 class Viewpoint : public SceneNode
 {
 
@@ -49,4 +50,6 @@ private:
   GLdouble    userMatrix[16], mouseMatrix[16];
 };
 
+} // namespace rgl 
+
 #endif // VIEWPOINT_HPP
