@@ -3,7 +3,11 @@
 
 #include "DeviceManager.hpp"
 
+using namespace rgl;
+
+namespace rgl {
 extern DeviceManager* deviceManager;
+}
 
 /* These defines are not in the installed version of R */
 #include "R.h"
@@ -11,10 +15,6 @@ extern DeviceManager* deviceManager;
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-extern "C" {
-EXPORT_SYMBOL SEXP rgl_setMouseCallbacks(SEXP button, SEXP begin, SEXP update, SEXP end);
-}
-
 static void userControl(void *userData, int mouseX, int mouseY)
 {
   SEXP fn = (SEXP)userData;
@@ -37,7 +37,7 @@ static void userCleanup(void **userData)
   }
 }
 
-SEXP rgl_setMouseCallbacks(SEXP button, SEXP begin, SEXP update, SEXP end)
+SEXP rgl::rgl_setMouseCallbacks(SEXP button, SEXP begin, SEXP update, SEXP end)
 {
   Device* device;
   if (deviceManager && (device = deviceManager->getCurrentDevice())) {
