@@ -130,6 +130,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace)
    {"rgl_light",		(DL_FUNC) &rgl_light, 3, aIID},
    {"rgl_pixels",		(DL_FUNC) &rgl_pixels, 5, aLIIIF},
    {"rgl_planes",		(DL_FUNC) &rgl_planes, 4, aIIDD},
+   {"rgl_clipplanes", 		(DL_FUNC) &rgl_planes, 4, aIIDD},
    {"rgl_abclines",		(DL_FUNC) &rgl_abclines, 4, aIIDD},
    {"rgl_primitive",		(DL_FUNC) &rgl_primitive, 5, aIIDDD},
    {"rgl_surface", 		(DL_FUNC) &rgl_surface, 13, aIIDDDDDDDDIII},
@@ -170,6 +171,7 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace)
    FUNDEF(rgl_light, 3),
    FUNDEF(rgl_pixels, 5),
    FUNDEF(rgl_planes, 4),
+   FUNDEF(rgl_clipplanes, 4),
    FUNDEF(rgl_abclines, 4),
    FUNDEF(rgl_primitive, 5),
    FUNDEF(rgl_surface, 13),
