@@ -3,8 +3,9 @@
 // ---------------------------------------------------------------------------
 #include "../gui.hpp"
 // ---------------------------------------------------------------------------
-namespace gui {
-// ---------------------------------------------------------------------------
+
+namespace rgl {
+
 class OSXGUIFactory : public GUIFactory
 {
 public:
@@ -13,8 +14,8 @@ public:
   WindowImpl* createWindowImpl(Window* w); 
   bool hasEventLoop();
 };
-// ---------------------------------------------------------------------------
-} // namespace gui
+
+} // namespace rgl
 // ---------------------------------------------------------------------------
 #endif // RGL_OSX_GUI_HPP
 
